You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by ja...@apache.org on 2007/06/12 05:45:16 UTC

svn commit: r546370 - in /webservices/axis2/trunk/java/modules: kernel/src/org/apache/axis2/description/ kernel/src/org/apache/axis2/engine/ webapp/src/main/webapp/axis2-web/

Author: jaliya
Date: Mon Jun 11 20:45:15 2007
New Revision: 546370

URL: http://svn.apache.org/viewvc?view=rev&rev=546370
Log:
Fix for the JIRA AXIS2-2642
https://issues.apache.org/jira/browse/AXIS2-2642
Engaged Module list are kept in AxisOperation as a list of modules while as a list of names in both AxisService and AxisServiceGroup. However, all of them had a getEngagedModules method whcih returns a list of modules at the AxisOperation and lists of module names at AxisService and AxisServiceGroup.

Now the getEngagedModules() method is refactored to getEngagedModulesNames() to remove the ambiguity of the names. We do not need to keep copies of engaged modules as it is available via the AxisConfig

Modified:
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperation.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisServiceGroup.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AddressingBasedDispatcher.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AxisConfiguration.java
    webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/ListServiceGroup.jsp
    webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listGroupService.jsp
    webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listService.jsp

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperation.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperation.java?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisOperation.java Mon Jun 11 20:45:15 2007
@@ -17,38 +17,27 @@
 package org.apache.axis2.description;
 
 import org.apache.axiom.om.util.UUIDGenerator;
-import org.apache.axiom.om.OMElement;
-import org.apache.axiom.om.OMNamespace;
-import org.apache.axiom.om.OMFactory;
-import org.apache.axiom.om.OMAbstractFactory;
 import org.apache.axis2.AxisFault;
-import org.apache.axis2.deployment.DeploymentConstants;
-import org.apache.axis2.util.WSDLSerializationUtil;
-import org.apache.axis2.util.JavaUtils;
 import org.apache.axis2.client.OperationClient;
 import org.apache.axis2.client.Options;
 import org.apache.axis2.context.ConfigurationContext;
 import org.apache.axis2.context.MessageContext;
 import org.apache.axis2.context.OperationContext;
 import org.apache.axis2.context.ServiceContext;
+import org.apache.axis2.deployment.DeploymentConstants;
 import org.apache.axis2.engine.AxisConfiguration;
 import org.apache.axis2.engine.AxisError;
 import org.apache.axis2.engine.MessageReceiver;
 import org.apache.axis2.i18n.Messages;
 import org.apache.axis2.modules.Module;
 import org.apache.axis2.phaseresolver.PhaseResolver;
+import org.apache.axis2.util.JavaUtils;
 import org.apache.axis2.wsdl.WSDLConstants;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import javax.xml.namespace.QName;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.Set;
-import java.util.Map;
-import java.net.URI;
+import java.util.*;
 
 public abstract class AxisOperation extends AxisDescription
         implements WSDLConstants {
@@ -468,7 +457,7 @@
      */
 
     /**
-     * Method getEngagedModules.
+     * Method getEngagedModulesNames.
      */
     public Collection getEngagedModules() {
         return engagedModules;

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisService.java Mon Jun 11 20:45:15 2007
@@ -20,38 +20,27 @@
 import org.apache.axiom.om.OMElement;
 import org.apache.axis2.AxisFault;
 import org.apache.axis2.Constants;
-import org.apache.axis2.description.java2wsdl.TypeTable;
-import org.apache.axis2.description.java2wsdl.DefaultSchemaGenerator;
-import org.apache.axis2.description.java2wsdl.Java2WSDLConstants;
-import org.apache.axis2.description.java2wsdl.SchemaGenerator;
 import org.apache.axis2.addressing.AddressingConstants;
 import org.apache.axis2.addressing.EndpointReference;
 import org.apache.axis2.client.Options;
 import org.apache.axis2.context.MessageContext;
-import org.apache.axis2.dataretrieval.AxisDataLocator;
-import org.apache.axis2.dataretrieval.AxisDataLocatorImpl;
-import org.apache.axis2.dataretrieval.DRConstants;
-import org.apache.axis2.dataretrieval.Data;
-import org.apache.axis2.dataretrieval.DataRetrievalException;
-import org.apache.axis2.dataretrieval.DataRetrievalRequest;
-import org.apache.axis2.dataretrieval.LocatorType;
-import org.apache.axis2.dataretrieval.OutputForm;
+import org.apache.axis2.dataretrieval.*;
+import org.apache.axis2.deployment.DeploymentConstants;
 import org.apache.axis2.deployment.util.PhasesInfo;
 import org.apache.axis2.deployment.util.Utils;
-import org.apache.axis2.deployment.DeploymentConstants;
-import org.apache.axis2.engine.AxisConfiguration;
-import org.apache.axis2.engine.DefaultObjectSupplier;
-import org.apache.axis2.engine.MessageReceiver;
-import org.apache.axis2.engine.ObjectSupplier;
-import org.apache.axis2.engine.ServiceLifeCycle;
+import org.apache.axis2.description.java2wsdl.DefaultSchemaGenerator;
+import org.apache.axis2.description.java2wsdl.Java2WSDLConstants;
+import org.apache.axis2.description.java2wsdl.SchemaGenerator;
+import org.apache.axis2.description.java2wsdl.TypeTable;
+import org.apache.axis2.engine.*;
 import org.apache.axis2.i18n.Messages;
 import org.apache.axis2.modules.Module;
 import org.apache.axis2.phaseresolver.PhaseResolver;
 import org.apache.axis2.transport.TransportListener;
 import org.apache.axis2.transport.http.server.HttpUtils;
+import org.apache.axis2.util.JavaUtils;
 import org.apache.axis2.util.Loader;
 import org.apache.axis2.util.XMLUtils;
-import org.apache.axis2.util.JavaUtils;
 import org.apache.axis2.wsdl.WSDLConstants;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -82,17 +71,7 @@
 import java.net.SocketException;
 import java.net.URL;
 import java.security.PrivilegedAction;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Date;
-import java.util.Enumeration;
-import java.util.HashMap;
-import java.util.Hashtable;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
+import java.util.*;
 
 /**
  * Class AxisService
@@ -124,7 +103,7 @@
     private ArrayList moduleRefs = null;
 
     // to store engaged modules
-    private ArrayList engagedModules = null;
+    private ArrayList engagedModulesNames = null;
 
     // to store the wsdl definition , which is build at the deployment time
     // to keep the time that last update time of the service
@@ -308,7 +287,7 @@
         httpLocationDispatcherMap = new HashMap();
         messageReceivers = new HashMap();
         moduleRefs = new ArrayList();
-        engagedModules = new ArrayList();
+        engagedModulesNames = new ArrayList();
         schemaList = new ArrayList();
         serviceClassLoader = (ClassLoader) org.apache.axis2.java.security.AccessController
                 .doPrivileged(new PrivilegedAction() {
@@ -517,10 +496,10 @@
     public void addOperation(AxisOperation axisOperation) {
         axisOperation.setParent(this);
 
-        Iterator modules = getEngagedModules().iterator();
+        Iterator moduleNames = getEngagedModulesNames().iterator();
 
-        while (modules.hasNext()) {
-            AxisModule module = (AxisModule) modules.next();
+        while (moduleNames.hasNext()) {
+            AxisModule module = (AxisModule) moduleNames.next();
             AxisServiceGroup parent = (AxisServiceGroup) getParent();
 
             try {
@@ -668,11 +647,11 @@
         if (axisModule == null) {
             throw new AxisFault(Messages.getMessage("modulenf"));
         }
-        Iterator itr_engageModules = engagedModules.iterator();
+        Iterator itr_engageModuleNames = engagedModulesNames.iterator();
         boolean isEngagable;
         String moduleName = axisModule.getName();
-        while (itr_engageModules.hasNext()) {
-            AxisModule module = (AxisModule) itr_engageModules.next();
+        while (itr_engageModuleNames.hasNext()) {
+            AxisModule module = (AxisModule) itr_engageModuleNames.next();
             String modu = module.getName();
             isEngagable = org.apache.axis2.util.Utils.checkVersion(moduleName, modu);
             if (!isEngagable) {
@@ -694,7 +673,7 @@
             AxisOperation axisOperation = (AxisOperation) operations.next();
             axisOperation.engageModule(axisModule);
         }
-        engagedModules.add(axisModule);
+        engagedModulesNames.add(axisModule);
     }
 
     /**
@@ -1071,12 +1050,12 @@
     }
 
     /**
-     * Method getEngagedModules.
+     * Method getEngagedModulesNames.
      *
      * @return Returns Collection.
      */
-    public Collection getEngagedModules() {
-        return engagedModules;
+    public Collection getEngagedModulesNames() {
+        return engagedModulesNames;
     }
 
     public URL getFileName() {
@@ -1400,7 +1379,7 @@
                 }
             }
         }
-        engagedModules.remove(module);
+        engagedModulesNames.remove(module);
     }
 
     /**
@@ -1422,9 +1401,9 @@
         if (module == null) {
             return false;
         }
-        Iterator engagedModuleItr = engagedModules.iterator();
-        while (engagedModuleItr.hasNext()) {
-            AxisModule axisModule = (AxisModule) engagedModuleItr.next();
+        Iterator engagedModuleNamesItr = engagedModulesNames.iterator();
+        while (engagedModuleNamesItr.hasNext()) {
+            AxisModule axisModule = (AxisModule) engagedModuleNamesItr.next();
             if (axisModule.getName().equals(module.getName())) {
                 return true;
             }

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisServiceGroup.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisServiceGroup.java?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AddressingBasedDispatcher.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AddressingBasedDispatcher.java Mon Jun 11 20:45:15 2007
@@ -59,6 +59,7 @@
     /**
      * @param msgctx
      * @throws org.apache.axis2.AxisFault
+     * @noinspection MethodReturnOfConcreteClass
      */
     public InvocationResponse invoke(MessageContext msgctx) throws AxisFault {
         // first check we can dispatch using the relates to
@@ -74,7 +75,8 @@
                         msgctx.getConfigurationContext()
                                 .getOperationContext(relatesTo);
 
-                if (operationContext != null) {
+                if (operationContext != null) //noinspection TodoComment
+                {
 //                    if(operationContext.isComplete()){
 //                        // If the dispatch happens because of the RelatesTo and the mep is complete
 //                        // we should throw a more descriptive fault.

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AxisConfiguration.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AxisConfiguration.java?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AxisConfiguration.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AxisConfiguration.java Mon Jun 11 20:45:15 2007
@@ -36,10 +36,10 @@
 import org.apache.commons.logging.LogFactory;
 
 import javax.xml.namespace.QName;
+import java.io.File;
 import java.net.URL;
 import java.security.PrivilegedAction;
 import java.util.*;
-import java.io.File;
 
 /**
  * Class AxisConfiguration

Modified: webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/ListServiceGroup.jsp
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/ListServiceGroup.jsp?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================
--- webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/ListServiceGroup.jsp (original)
+++ webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/ListServiceGroup.jsp Mon Jun 11 20:45:15 2007
@@ -4,6 +4,7 @@
 <%@ page import="javax.xml.namespace.QName" %>
 <%@ page import="java.util.ArrayList" %>
 <%@ page import="java.util.Iterator" %>
+<%@ page import="java.util.Collection"%>
 <%@ page contentType="text/html;charset=UTF-8" language="java" %>
 <%
  /*
@@ -33,7 +34,7 @@
     while (axisServiceGroupIter.hasNext()) {
         AxisServiceGroup axisServiceGroup = (AxisServiceGroup) axisServiceGroupIter.next();
         String groupName = axisServiceGroup.getServiceGroupName();
-        ArrayList modules = axisServiceGroup.getEngagedModules();
+        Collection moduleNames = axisServiceGroup.getEngagedModulesNames();
         Iterator axisServiceIter = axisServiceGroup.getServices();
 %>
 <h2><%=groupName%></h2><ul>
@@ -49,12 +50,12 @@
     %>
 </ul>
 <%
-    if (modules.size() > 0) {
+    if (moduleNames.size() > 0) {
 %>
 <I>Engaged modules</I><ul>
     <%
-        for (int i = 0; i < modules.size(); i++) {
-            String modulDesc = (String) modules.get(i);
+         for (Iterator iteratorm = moduleNames.iterator(); iteratorm.hasNext();) {
+              String modulDesc = (String) iteratorm.next();
     %>
     <li><%=modulDesc%></li>
     <%

Modified: webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listGroupService.jsp
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listGroupService.jsp?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================
--- webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listGroupService.jsp (original)
+++ webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listGroupService.jsp Mon Jun 11 20:45:15 2007
@@ -58,13 +58,13 @@
 <h4>Service Description : <font color="black"><%=axisService.getServiceDescription()%></h4>
 <i><font color="blue">Service Status : <%=axisService.isActive() ? "Active" : "InActive"%></font></i><br/>
 <%
-  Collection engagedModules = axisService.getEngagedModules();
+  Collection engagedModulesNames = axisService.getEngagedModulesNames();
   String moduleName;
-  if (engagedModules.size() > 0) {
+  if (engagedModulesNames.size() > 0) {
 %>
 <i>Engaged Modules for the Axis Service</i><ul>
   <%
-    for (Iterator iteratorm = engagedModules.iterator(); iteratorm.hasNext();) {
+    for (Iterator iteratorm = engagedModulesNames.iterator(); iteratorm.hasNext();) {
       AxisModule axisOperation = (AxisModule) iteratorm.next();
       moduleName = axisOperation.getName();
   %><li><%=moduleName%></li>
@@ -84,12 +84,12 @@
     AxisOperation axisOperation = (AxisOperation) operations.next();
 %><li><%=axisOperation.getName().getLocalPart()%></li>
   <%
-    engagedModules = axisOperation.getEngagedModules();
-    if (engagedModules.size() > 0) {
+    engagedModulesNames = axisOperation.getEngagedModules();
+    if (engagedModulesNames.size() > 0) {
   %>
   <br><i>Engaged Modules for the Operation</i><ul>
   <%
-    for (Iterator iterator2 = engagedModules.iterator(); iterator2.hasNext();) {
+    for (Iterator iterator2 = engagedModulesNames.iterator(); iterator2.hasNext();) {
       AxisModule moduleDecription = (AxisModule) iterator2.next();
       moduleName = moduleDecription.getName();
   %><li><%=moduleName%></li><br><%

Modified: webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listService.jsp
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listService.jsp?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================
--- webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listService.jsp (original)
+++ webservices/axis2/trunk/java/modules/webapp/src/main/webapp/axis2-web/listService.jsp Mon Jun 11 20:45:15 2007
@@ -75,7 +75,7 @@
         <h4>Service Description : <font color="black"><%=serviceDescription%></h4>
 <i><font color="blue">Service Status : <%=axisService.isActive() ? "Active" : "InActive"%></font></i><br>
 <%
-    Collection engagedModules = axisService.getEngagedModules();
+    Collection engagedModules = axisService.getEngagedModulesNames();
     String moduleName;
     boolean modules_present = false;
     if (engagedModules.size() > 0) {



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisServiceGroup.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/description/AxisServiceGroup.java Mon Jun 11 20:45:15 2007
@@ -25,6 +25,7 @@
 import org.apache.axis2.util.Utils;
 
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.Iterator;
 
@@ -35,8 +36,8 @@
     // to store module ref at deploy time parsing
     private ArrayList modulesList = new ArrayList();
 
-    // to store service Group engagedModules name
-    private ArrayList engagedModules;
+    // to store service Group engagedModulesNames name
+    private ArrayList engagedModulesNames;
 
     // to store modeule configuration info
     private HashMap moduleConfigmap;
@@ -49,7 +50,7 @@
 
     public AxisServiceGroup() {
         moduleConfigmap = new HashMap();
-        engagedModules = new ArrayList();
+        engagedModulesNames = new ArrayList();
     }
 
     public AxisServiceGroup(AxisConfiguration axisDescription) {
@@ -89,10 +90,10 @@
         AxisConfiguration axisConfig = (AxisConfiguration) getParent();
 
         if (axisConfig != null) {
-            Iterator modules = this.engagedModules.iterator();
+            Iterator moduleNames = this.engagedModulesNames.iterator();
 
-            while (modules.hasNext()) {
-                String moduleName = (String) modules.next();
+            while (moduleNames.hasNext()) {
+                String moduleName = (String) moduleNames.next();
                 AxisModule axisModule = axisConfig.getModule(moduleName);
 
                 if (axisModule != null) {
@@ -121,10 +122,10 @@
         AxisConfiguration axisConfig = (AxisConfiguration) getParent();
 
         if (axisConfig != null) {
-            Iterator modules = this.engagedModules.iterator();
+            Iterator moduleNames = this.engagedModulesNames.iterator();
 
-            while (modules.hasNext()) {
-                String moduleName = (String) modules.next();
+            while (moduleNames.hasNext()) {
+                String moduleName = (String) moduleNames.next();
                 AxisModule axisModule = axisConfig.getModule(moduleName);
 
                 if (axisModule != null) {
@@ -147,17 +148,17 @@
     }
 
     public void addToengagedModules(String moduleName) {
-        engagedModules.add(moduleName);
+        engagedModulesNames.add(moduleName);
     }
 
     public void removeFromEngageList(String moduleName) {
-        engagedModules.remove(moduleName);
+        engagedModulesNames.remove(moduleName);
     }
 
     public void engageModule(AxisModule module) throws AxisFault {
         String moduleName = module.getName();
         boolean isEngagable;
-        for (Iterator iterator = engagedModules.iterator(); iterator.hasNext();) {
+        for (Iterator iterator = engagedModulesNames.iterator(); iterator.hasNext();) {
             String modu = (String) iterator.next();
             isEngagable = Utils.checkVersion(moduleName, modu);
             if (!isEngagable) {
@@ -193,8 +194,8 @@
         return (AxisConfiguration) getParent();
     }
 
-    public ArrayList getEngagedModules() {
-        return engagedModules;
+    public Collection getEngagedModulesNames() {
+        return engagedModulesNames;
     }
 
     public ModuleConfiguration getModuleConfig(String moduleName) {
@@ -249,7 +250,7 @@
             return false;
         }
 
-        for (Iterator engagedModuleItr = engagedModules.iterator();
+        for (Iterator engagedModuleItr = engagedModulesNames.iterator();
              engagedModuleItr.hasNext();) {
             String axisModule = (String) engagedModuleItr.next();
             if (axisModule.equals(module.getName())) {

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AddressingBasedDispatcher.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/engine/AddressingBasedDispatcher.java?view=diff&rev=546370&r1=546369&r2=546370
==============================================================================